@@ -17,6 +17,7 @@
 */
 
 #include "queryserviceclient.h"
+#include <akdebug.h>
 #include "dbusoperators.h"
 #include "result.h"
 #include "queryserviceinterface.h"
@@ -97,7 +98,7 @@ public:
 
 void Nepomuk::Query::QueryServiceClient::Private::_k_finishedListing()
 {
-    emit q->finishedListing();
+    Q_EMIT q->finishedListing();
     if( loop ) {
         q->close();
     }
@@ -121,7 +122,7 @@ bool Nepomuk::Query::QueryServiceClient::Private::handleQueryReply( QDBusReply<Q
         return true;
     }
     else {
-        qDebug() << "Query failed:" << r.error().message();
+        akError() << "Query failed:" << r.error().message();
         return false;
     }
 }
@@ -158,7 +159,7 @@ bool Nepomuk::Query::QueryServiceClient::query( const QString& query, const QHas
         return d->handleQueryReply( d->queryServiceInterface->sparqlQuery( query, encodedRps ) );
     }
     else {
-        qDebug() << "Could not contact query service.";
+        akDebug() << "Could not contact query service.";
         return false;
     }
 }
@@ -182,7 +183,7 @@ bool Nepomuk::Query::QueryServiceClient::blockingQuery( const QString& q, const
 void Nepomuk::Query::QueryServiceClient::close()
 {
     if ( d->queryInterface ) {
-        qDebug() << Q_FUNC_INFO;
+        akDebug() << Q_FUNC_INFO;
         d->queryInterface->close();
         delete d->queryInterface;
         d->queryInterface = 0;
